==> apache-seatunnel-2.3.10-src.tar.gz: apache-seatunnel-2.3.10-src/docs/zh/connector-v2/changelog/connector-google-sheets.md <==
<details><summary> Change Log </summary>

| Change | Commit | Version |
| --- | --- | --- |
|[improve] google sheets options (#8922)|https://github.com/apache/seatunnel/commit/48ede612dc| dev |
|[Improve] restruct connector common options (#8634)|https://github.com/apache/seatunnel/commit/f3499a6eeb| dev |
|[Improve][API] Make sure the table name in TablePath not be null (#7252)|https://github.com/apache/seatunnel/commit/764d8b0bc8|2.3.7|
|[Feature][Kafka] Support multi-table source read  (#5992)|https://github.com/apache/seatunnel/commit/60104602d1|2.3.6|
|[Improve][Connector-V2] Replace CommonErrorCodeDeprecated.JSON_OPERATION_FAILED (#5978)|https://github.com/apache/seatunnel/commit/456cd17714|2.3.4|
|[Improve][Common] Introduce new error define rule (#5793)|https://github.com/apache/seatunnel/commit/9d1b2582b2|2.3.4|
|Support config column/primaryKey/constraintKey in schema (#5564)|https://github.com/apache/seatunnel/commit/eac76b4e50|2.3.4|
|Merge branch &#x27;dev&#x27; into merge/cdc|https://github.com/apache/seatunnel/commit/4324ee1912|2.3.1|
|[Improve][Project] Code format with spotless plugin.|https://github.com/apache/seatunnel/commit/423b583038|2.3.1|
|[improve][api] Refactoring schema parse (#4157)|https://github.com/apache/seatunnel/commit/b2f573a13e|2.3.1|
|[Improve][build] Give the maven module a human readable name (#4114)|https://github.com/apache/seatunnel/commit/d7cd601051|2.3.1|
|[Improve][Project] Code format with spotless plugin. (#4101)|https://github.com/apache/seatunnel/commit/a2ab166561|2.3.1|
|[Feature][shade][Jackson] Add seatunnel-jackson module (#3947)|https://github.com/apache/seatunnel/commit/5d8862ec9c|2.3.1|
|[Feature][Connector] add get source method to all source connector (#3846)|https://github.com/apache/seatunnel/commit/417178fb84|2.3.1|
|[Hotfix][OptionRule] Fix option rule about all connectors (#3592)|https://github.com/apache/seatunnel/commit/226dc6a119|2.3.0|
|[Improve][Connector-V2][GoogleSheets] Unified exception for GoogleSheets source connector (#3524)|https://github.com/apache/seatunnel/commit/eb42d629ad|2.3.0|
|[Feature][Connector-V2][Google Sheets] Add Google Sheets option rules (#3364)|https://github.com/apache/seatunnel/commit/da33f730ca|2.3.0|
|fix: schema get error (#3361)|https://github.com/apache/seatunnel/commit/fdaa85ed24|2.3.0|
|[Feature][Connector-V2][GoogleSheets] Support GoogleSheets Source (#3185)|https://github.com/apache/seatunnel/commit/60ecc6428b|2.3.0|

</details>

==> apache-seatunnel-2.3.12-src.tar.gz: apache-seatunnel-2.3.12-src/docs/zh/connector-v2/changelog/connector-google-sheets.md <==
<details><summary> Change Log </summary>

| Change | Commit | Version |
| --- | --- | --- |
|[improve] google sheets options (#8922)|https://github.com/apache/seatunnel/commit/48ede612dc|2.3.10|
|[Improve] restruct connector common options (#8634)|https://github.com/apache/seatunnel/commit/f3499a6eeb|2.3.10|
|[Improve][API] Make sure the table name in TablePath not be null (#7252)|https://github.com/apache/seatunnel/commit/764d8b0bc8|2.3.7|
|[Feature][Kafka] Support multi-table source read  (#5992)|https://github.com/apache/seatunnel/commit/60104602d1|2.3.6|
|[Improve][Connector-V2] Replace CommonErrorCodeDeprecated.JSON_OPERATION_FAILED (#5978)|https://github.com/apache/seatunnel/commit/456cd17714|2.3.4|
|[Improve][Common] Introduce new error define rule (#5793)|https://github.com/apache/seatunnel/commit/9d1b2582b2|2.3.4|
|Support config column/primaryKey/constraintKey in schema (#5564)|https://github.com/apache/seatunnel/commit/eac76b4e50|2.3.4|
|Merge branch &#x27;dev&#x27; into merge/cdc|https://github.com/apache/seatunnel/commit/4324ee1912|2.3.1|
|[Improve][Project] Code format with spotless plugin.|https://github.com/apache/seatunnel/commit/423b583038|2.3.1|
|[improve][api] Refactoring schema parse (#4157)|https://github.com/apache/seatunnel/commit/b2f573a13e|2.3.1|
|[Improve][build] Give the maven module a human readable name (#4114)|https://github.com/apache/seatunnel/commit/d7cd601051|2.3.1|
|[Improve][Project] Code format with spotless plugin. (#4101)|https://github.com/apache/seatunnel/commit/a2ab166561|2.3.1|
|[Feature][shade][Jackson] Add seatunnel-jackson module (#3947)|https://github.com/apache/seatunnel/commit/5d8862ec9c|2.3.1|
|[Feature][Connector] add get source method to all source connector (#3846)|https://github.com/apache/seatunnel/commit/417178fb84|2.3.1|
|[Hotfix][OptionRule] Fix option rule about all connectors (#3592)|https://github.com/apache/seatunnel/commit/226dc6a119|2.3.0|
|[Improve][Connector-V2][GoogleSheets] Unified exception for GoogleSheets source connector (#3524)|https://github.com/apache/seatunnel/commit/eb42d629ad|2.3.0|
|[Feature][Connector-V2][Google Sheets] Add Google Sheets option rules (#3364)|https://github.com/apache/seatunnel/commit/da33f730ca|2.3.0|
|fix: schema get error (#3361)|https://github.com/apache/seatunnel/commit/fdaa85ed24|2.3.0|
|[Feature][Connector-V2][GoogleSheets] Support GoogleSheets Source (#3185)|https://github.com/apache/seatunnel/commit/60ecc6428b|2.3.0|

</details>
